@@ -84,6 +84,7 @@ struct _GdmChooserHost {
 static const gchar *scanning_message = N_("Please wait: scanning local network...");
 static const gchar *empty_network = N_("No serving hosts were found.");
 static const gchar *active_network = N_("Choose a ho_st to connect to:");
+static void gdm_chooser_cancel (/*void*/);
 
 /* XDM chooser style stuff */
 static gchar *xdm_address = NULL;
@@ -91,7 +92,6 @@ static gchar *client_address = NULL;
 static gint connection_type = 0;
 
 /* Exported for glade */
-void gdm_chooser_cancel (/*void*/);
 void gdm_chooser_add_host (void);
 void gdm_chooser_add_entry_changed (void);
 void gdm_chooser_manage (GtkButton *button, gpointer data);
@@ -1535,8 +1535,8 @@ gdm_chooser_add_entry_changed (void)
 	gtk_widget_set_sensitive (add_button, ! ve_string_empty (name));
 }
 
-void
-gdm_chooser_cancel (/*void*/)
+static void
+gdm_chooser_cancel (int sig)
 {
     if (scan_time_handler > 0) {
 	    g_source_remove (scan_time_handler);
@@ -1798,6 +1798,8 @@ gdm_read_config (void)
 	gdm_config_get_bool   (GDM_KEY_MULTICAST);
 
 	gdmcomm_comm_bulk_stop ();
+
+	return FALSE;
 }
 
 static gboolean
@@ -1905,7 +1907,7 @@ GOptionEntry chooser_options [] = {
           N_("Client address to return in response to xdm"), N_("ADDRESS") },
        { "connectionType", '\0', 0, G_OPTION_ARG_INT, &connection_type,
           N_("Connection type to return in response to xdm"), N_("TYPE") },
-       { G_OPTION_REMAINING, NULL, 0, G_OPTION_ARG_STRING_ARRAY, &chooser_hosts,
+       { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &chooser_hosts,
           NULL, NULL },
        { NULL }
  };
@@ -2065,7 +2067,7 @@ main (int argc, char *argv[])
 	    }
     }
     gdm_chooser_xdmcp_init (hosts_opt);
-    g_strfreev (chooser_hosts);
+    g_strfreev (hosts_opt);
 
     sid = g_signal_lookup ("event",
 				 GTK_TYPE_WIDGET);
